@@ -33,11 +33,12 @@ import time
 from .ui_utils import menu_options, app_header, format_msg
 from .utils import (get_correct_answer, ask_yes_no, path_fixer,
                     SetupConfig, _directory_fixer, install_client_package,
-                    write_client_config)
+                    write_client_config, FROZEN)
 
 # framework stuff
 from not_so_tuf import NotSoTuf
 from not_so_tuf.client import Client
+from not_so_tuf.compat import input_, print_function
 from not_so_tuf.filecrypt import FileCrypt
 from not_so_tuf.key_handler import KeyHandler
 from not_so_tuf.package_handler import PackageHandler
@@ -52,8 +53,6 @@ h = logging.NullHandler()
 h.setLevel(logging.DEBUG)
 log.addHandler(h)
 
-FROZEN = getattr(sys, 'frozen', False)
-
 
 class Ui(object):
 
@@ -84,15 +83,15 @@ class Ui(object):
                    ('Upload', self.upload), ('Keys', self.keys),
                    ('Settings', self.settings), ('Quit', self.quit)]
 
-        print app_header()
+        print(app_header())
         next = menu_options(options)
         return next()
 
     def sign_updates(self):
         log.debug('Sign Updates Menu')
-        print app_header('Sign Updates')
+        print(app_header('Sign Updates'))
         msg = 'Make sure updates are in "new" folder then press "1" to start'
-        print format_msg(msg)
+        print(format_msg(msg))
         options = [('Start', self.start_sign_updates),
                    ('Go Back', self.main)]
         next = menu_options(options)
@@ -100,26 +99,26 @@ class Ui(object):
 
     def start_sign_updates(self):
         log.debug('Signing updates')
-        print app_header('Signing updates...')
-        print format_msg('Please wait...')
+        print(app_header('Signing updates...'))
+        print(format_msg('Please wait...'))
         package_handler = PackageHandler(self.nst)
         package_handler.setup()
         package_handler.update_package_list()
         key_handler = KeyHandler(self.nst)
         key_handler.sign_update()
         package_handler.deploy()
-        print 'Update signing complete...'
+        print('Update signing complete...')
         time.sleep(3)
         self.main()
 
     def upload(self):
         log.debug('Upload')
         self.uploader = Uploader(self.nst)
-        print app_header('Upload')
+        print(app_header('Upload'))
         msg = ('Select destination to begin upload.  If you don\'t have any '
                'upload settings, go to settings menu, then update settings or '
                'you\'ll get an error.')
-        print format_msg(msg)
+        print(format_msg(msg))
         options = [('S3', self.s3_upload), ('SCP', self.scp_upload),
                    ('Go Back', self.main)]
         next = menu_options(options)
@@ -127,7 +126,7 @@ class Ui(object):
 
     def s3_upload(self):
         log.debug('S3 Uploader')
-        print app_header('S3 Uploader')
+        print(app_header('S3 Uploader'))
         self.uploader.set_uploader('s3')
         if self.uploader.ready:
             self.uploader.upload()
@@ -138,13 +137,13 @@ class Ui(object):
             msg = ('I told you to update your settings right? Right! Press '
                    'enter to return to main menu and please this time update '
                    'your settings.')
-            print format_msg(msg)
+            print(format_msg(msg))
             raw_input()
             self.main()
 
     def scp_upload(self):
         log.debug('SCP Uploader')
-        print app_header('SCP Uploader')
+        print(app_header('SCP Uploader'))
         self.uploader.set_uploader('scp')
         if self.uploader.ready:
             self.uploader.upload()
@@ -153,7 +152,7 @@ class Ui(object):
             msg = ('I told you to update your settings right? Right! Press '
                    'enter to return to main menu and please this time update '
                    'your settings.')
-            print format_msg(msg)
+            print(format_msg(msg))
             raw_input()
             self.main()
 
@@ -164,7 +163,7 @@ class Ui(object):
                     self.private_key_copy),
                    ('Go Back', self.main)]
                    # ('Replace Keys', self.main), ('Go Back', self.main)]
-        print app_header('Keys')
+        print(app_header('Keys'))
         next = menu_options(options)
         return next()
 
@@ -195,7 +194,7 @@ class Ui(object):
 
     def settings(self):
         log.debug('Settings Menu')
-        print app_header('Settings')
+        print(app_header('Settings'))
         options = [('View Settings', self.view_settings),
                    ('Update Settings', self.update_settings),
                    ('Decrypt and Copy Config', self.copy_decrypted_config),
@@ -208,11 +207,11 @@ class Ui(object):
 
     def delete_password(self):
         log.warning('About to delete password!')
-        print app_header('Proceed with Caution')
+        print(app_header('Proceed with Caution'))
         msg = ('Deleting you password will render you encrypted config and '
                'private key file useless. Make sure you have a decrypted '
                'copy of both.')
-        print format_msg(msg)
+        print(format_msg(msg))
         answer = ask_yes_no('Are you sure you want to continue?\nSelecting no '
                             'will return you to the main menu!', default='no')
         if not answer:
@@ -223,29 +222,29 @@ class Ui(object):
                             'not going back.  You have been warned.',
                             default='y')
         if answer:
-            self.copy_decrypted_config
-            self.copy_decrypted_private_key
+            self.copy_decrypted_config()
+            self.private_key_copy()
         self.delete_password()
 
     def view_settings(self):
         log.debug('View Settings Menu')
         for k, v in self.config.__dict__.items():
-            print k.ljust(20), v
+            print(k.ljust(20), v)
         raw_input('Press enter to continue')
         return self.settings()
 
     def update_settings(self):
         log.debug('Update Settings Menu')
-        print app_header('Update Settings')
+        print(app_header('Update Settings'))
         msg = ('Enter the number of each item you\'d like to update.')
-        print format_msg(msg)
-        print format_msg('Examples:')
-        print format_msg('-->13 ')
-        print format_msg('-->235 ')
-        print format_msg('-->513')
-        print format_msg('Then press Enter')
-        print ('1. App Name\n2. Dev Data Dir\n3. Update Url\n4. Update SSH '
-               'settings\n5. Update S3 settings\n')
+        print(format_msg(msg))
+        print(format_msg('Examples:'))
+        print(format_msg('-->13 '))
+        print(format_msg('-->235 '))
+        print(format_msg('-->513'))
+        print(format_msg('Then press Enter'))
+        print(('1. App Name\n2. Dev Data Dir\n3. Update Url\n4. Update SSH '
+               'settings\n5. Update S3 settings\n'))
         answers = raw_input('-->')
 
         if '1' in answers:
@@ -288,20 +287,20 @@ class Ui(object):
                                                          required=True)
 
         self.save_config(self.config)
-        print 'Saving new config....'
+        print('Saving new config....')
         time.sleep(3)
         return self.main()
 
     def quit(self):
         log.debug('Quitting')
-        print 'See Ya!'
+        print('See Ya!')
         sys.exit()
 
     def initial_setup(self):
         log.debug('Initial Setup Menu')
-        print app_header('Initial Setup')
+        print(app_header('Initial Setup'))
         msg = ('You should only have to run this once.')
-        print format_msg(msg)
+        print(format_msg(msg))
         options = [('Begin Setup', self.start_intial_setup),
                    ('Go Back', self.main)]
         next = menu_options(options)
@@ -309,8 +308,8 @@ class Ui(object):
 
     def start_intial_setup(self):
         log.debug('Starting initial setup')
-        print app_header('Setup Assistant')
-        print format_msg('Let\'s begin...')
+        print(app_header('Setup Assistant'))
+        print(format_msg('Let\'s begin...'))
 
         self.config.APP_NAME = get_correct_answer('Please enter app name',
                                                   default='Not-So-TUF')
@@ -385,10 +384,10 @@ class Ui(object):
         self.save_config(self.config)
         package_handler = PackageHandler(self.nst)
         package_handler.setup()
-        print 'Making keys...'
+        print('Making keys...')
         self.make_keys()
-        print app_header('Setup Complete')
-        print format_msg('Now let\'s update some apps')
+        print(app_header('Setup Complete'))
+        print(format_msg('Now let\'s update some apps'))
         time.sleep(3)
 
     def save_config(self, obj):
@@ -400,7 +399,7 @@ class Ui(object):
         with open(filename, 'w') as f:
             f.write(pickle.dumps(obj))
         fc.encrypt()
-        write_config(self.nst)
+        write_client_config(self.nst)
 
     def load_config(self):
         log.debug('Loading Config')
@@ -410,7 +409,7 @@ class Ui(object):
         with open(filename, 'r') as f:
             config_data = pickle.loads(f.read())
         fc.encrypt()
-        write_config(config_data)
+        write_client_config(config_data)
         return config_data
 
     def copy_decrypted_config(self):
@@ -435,7 +434,7 @@ class Ui(object):
 class ClientConfig(object):
 
     UPDATE_URL = 'https://s3-us-west-1.amazonaws.com/not-so-tuf/'
-    PUBLIC_KEY = (16464922665638673681992463013273935612664219094906980149897613483558764958275503471833999796774944451919679352299199781040261183626243789235159282484489660866211751942888040512642103075255732190154437871072326800313353343988071645793491504044388864374910418983325794095950121251375913490389709129928619827303368362856224581261135920008510653620012541583622789200202174035822993035846677533547389325544764270670429010858826140320098873827212627840823767544126373206301938873536107735052145489782939917808169280407467079055393335221958452100971113008041835393071679231080475062804424979544387709688694450412240360063013L, 65537)
+    PUBLIC_KEY = (16464922665638673681992463013273935612664219094906980149897613483558764958275503471833999796774944451919679352299199781040261183626243789235159282484489660866211751942888040512642103075255732190154437871072326800313353343988071645793491504044388864374910418983325794095950121251375913490389709129928619827303368362856224581261135920008510653620012541583622789200202174035822993035846677533547389325544764270670429010858826140320098873827212627840823767544126373206301938873536107735052145489782939917808169280407467079055393335221958452100971113008041835393071679231080475062804424979544387709688694450412240360063013, 65537)
 
 
 def main():
@@ -443,8 +442,8 @@ def main():
         if FROZEN:
             nst = NotSoTuf(__name__, ClientConfig())
             client = Client(nst)
-            print 'Current Version {}'.format(__version__)
-            print '\nChecking for updates...'
+            print('Current Version {}'.format(__version__))
+            print('\nChecking for updates...')
             update = client.update_check('Not So TUF', __version__)
             if update and not client.up_to_date:
                 client.install_restart()
@@ -454,7 +453,7 @@ def main():
             ui.start()
         except KeyboardInterrupt:
             # ToDo: Add clean up stuff here
-            print '\n\nExited by user'
+            print('\n\nExited by user')
     except Exception as e:
-        print str(e)
+        print(str(e))
         log.error(str(e), exc_info=True)
