@@ -20,6 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+
 import hashlib
 import logging
 import os
@@ -27,12 +28,15 @@ import shutil
 import sys
 import urllib2
 
+from not_so_tuf.compat import print_function
 from not_so_tuf.utils import _cwd
 from not_so_tuf.version import __version__
 
 
 log = logging.getLogger(__name__)
 
+FROZEN = getattr(sys, 'frozen', False)
+
 
 class SetupConfig(object):
     # If left None "Not_So_TUF" will be used
@@ -112,9 +116,9 @@ def get_correct_answer(question, default=None, required=False):
         prompt = question + msg + '\n--> '
         answer = raw_input(prompt)
         if answer == '' and required:
-            print 'You have to enter a value\n\n'
+            print_function('You have to enter a value\n\n')
             raw_input('Press enter to continue')
-            print '\n\n'
+            print_function('\n\n')
             continue
         if answer == '' and default is not None:
             answer = default
@@ -143,9 +147,9 @@ def ask_yes_no(question, default='no'):
         elif answer in no:
             return False
         else:
-            print 'Please answer yes or no only!\n'
+            print_function('Please answer yes or no only!\n')
             raw_input('Press enter to continue')
-            print '\n\n\n\n'
+            print_function('\n\n\n\n')
 
 
 # Fixed path to work without quotes
@@ -195,7 +199,7 @@ def _directory_fixer(_dir):
 
 
 def install_client_package():
-    files = ['__init__.py', 'file_downloader.py', 'client.py',
+    files = ['__init__.py', 'downloader.py', 'client.py',
              'utils.py', 'patcher.py', 'version.py']
     package_name = 'not_so_tuf'
     dir_ = os.path.abspath(sys._MEIPASS)
@@ -213,15 +217,30 @@ def install_client_package():
 
 
 def write_client_config(config_object):
-    package_dir = os.path.join(_cwd, 'not_so_tuf')
-    with ChDir(package_dir):
-        with open('client_config.py', 'w') as f:
-            f.write('class ClientConfig(object):')
-            f.write('\n')
-            f.write('\tUPDATE_URL = {}'.format(config_object.UPDATE_URL))
-            f.write('\tPUBLIC_KEY = {}'.format(config_object.PUBLIC_KEY))
-            f.write('\n')
-    log.debug('Wrote client config')
+    if FROZEN:
+        package_dir = os.path.join(_cwd, 'not_so_tuf')
+        if getattr(config_object, 'UPDATE_URL', False):
+            update_url = config_object.UPDATE_URL
+        else:
+            update_url = None
+
+        if getattr(config_object, 'PUBLIC_KEY', False):
+            pub_key = config_object.PUBLIC_KEY
+        else:
+            pub_key = None
+
+        with ChDir(package_dir):
+            with open('client_config.py', 'w') as f:
+                f.write('class ClientConfig(object):')
+                f.write('\n')
+                f.write('\n')
+                f.write('\tUPDATE_URL = "{}"'.format(update_url))
+                f.write('\n')
+                f.write('\tPUBLIC_KEY = {}'.format(pub_key))
+                f.write('\n')
+        log.debug('Wrote client config')
+    else:
+        log.debug('Did not write client config -> NOT FROZEN')
 
 
 # Used to prevent sending out updates with debug
