@@ -74,8 +74,7 @@ class NotSoTuf(object):
         self.config.from_object(obj)
         if self.config.get('DEV_DATA_DIR', None) is None:
             logger.info('Using default directory')
-            self.config['DEV_DATA_DIR'] = os.path.join(self.real_path,
-                                                       'data')
+            self.config['DEV_DATA_DIR'] = os.path.join(self.real_path)
         if self.config.get('APP_NAME', None) is None:
             self.config['APP_NAME'] = 'Not_So_TUF'
 
