@@ -29,7 +29,7 @@ import sys
 import urllib2
 from zipfile import ZipFile
 
-from .file_downloader import FileDownloader
+from .downloader import FileDownloader
 from .patcher import Patcher
 from .utils import (ChDir, rsa_verify, _version_string_to_tuple,
                     _version_tuple_to_string, platform_)
