@@ -27,7 +27,7 @@ import os
 import shutil
 
 from . import KeyHandlerError
-from .utils import FileCrypt
+from .filecrypt import FileCrypt
 
 try:
     import rsa
