@@ -241,6 +241,7 @@ class PackageHandler(object):
         """
         log.info('Checking file list for {}'.format(package_name))
         files = self.json_data['y_data']
+        latest = self.json_data.get('latest', None)
         package_name = self._remove_ext(self._remove_version_number(
                                         package_name))
         package_name = self._remove_platform(package_name)
@@ -249,6 +250,9 @@ class PackageHandler(object):
             log.info('Adding {} to file list'.format(package_name))
             self.json_data['y_data'][package_name] = {}
 
+        if latest is None:
+            self.json_data['latest'] = {package_name: ''}
+
     def _update_version_file(self):
         """Updates version file with package meta-data
         """
@@ -284,6 +288,8 @@ class PackageHandler(object):
                 log.debug('Appending info data to version file')
                 self.json_data['y_data'][name][version][p['platform']] = info
 
+            self.json_data['latest'][name] = version
+
     def _get_package_list(self):
         """Adds compatible packages to internal package manifest
         for futher processing
@@ -334,7 +340,7 @@ class PackageHandler(object):
                         break
 
     def _get_platform(self, name):
-        platform_name = re.compile('[macnixw0-9]{3,5}').findall(name)[0]
+        platform_name = re.compile('[macnixw64]{3,5}').findall(name)[0]
         log.debug('Platform name is: {}'.format(platform_name))
         return platform_name
 
