@@ -26,7 +26,7 @@ import logging
 import os
 import sys
 
-from .file_downloader import FileDownloader
+from .downloader import FileDownloader
 from .utils import (ChDir, _version_string_to_tuple,
                     _version_tuple_to_string, platform_)
 
